@@ -1,4 +1,4 @@
-import loader
+from .loader import encrypt_file, gen_key
 import click
 
 @click.group()
@@ -10,13 +10,13 @@ def cmd():
 @click.argument('keyfile')
 @click.argument('file_path')
 def encrypt(keyfile, file_path):
-    loader.encrypt_file(file_path, keyfile)
+    encrypt_file(file_path, keyfile)
     click.echo('encrypted!')
 
 
 @cmd.command()
 def genkey():
-    loader.gen_key()
+    gen_key()
 
 
 cli = click.CommandCollection(sources=[cmd,])
